;define different breeds of agents available in the model.
breed [national-forces national-force]
breed [opposition-forces opposition-force]
breed [russian-forces russian-force]
breed [russian-specialforces russian-specialforce]
breed [american-specialforces american-specialforce]
breed [boats boat]
breed [airplanes airplane]
breed [rockets rocket]

;define globals, globals are variables that can used anywhere after they are "set"
globals [american-publicapproval american-cost russian-cost russian-profit american-missile-boat-spawned check-american-missilestrike american-airplane-boat-spawned check-american-airstrike check-american-specialforces check-russian-intervention check-russian-specialforces check-russian-airstrike global-conflict-level global-conflict-timer]

;patches and agents can own different variables, they are defined below.
patches-own[id]
turtles-own[armour arms proficiency typeid target]

;setup is run only once, when the setup button is pressed in the graphical interface. It clears the model and then sets up the model.
to setup
  clear-all

  import-pcolors "syria.png"
  ask patches with [pcolor >= 25 and pcolor <= 80][set pcolor green + 2 set id "conflictcountry"]

  set-default-shape opposition-forces "person"
  set-default-shape russian-forces "person"
  set-default-shape national-forces "person"
  set-default-shape american-specialforces "person"
  set-default-shape russian-specialforces "person"
  set-default-shape rockets "rocket"
  set-default-shape boats "boat top"
  set-default-shape airplanes "airplane"

  spawn-national-forces
  spawn-opposition-forces

  ask national-forces [set armour 0.5 set arms 1 set proficiency 0.5]
  ask opposition-forces [set armour 0.5 set arms 0.5 set proficiency 0.2]

  set global-conflict-level 50
  set global-conflict-timer 0
  set american-publicapproval 65
  set american-cost 0
  set russian-cost 0
  set russian-profit 0

  set american-missile-boat-spawned false
  set check-american-missilestrike false
  set american-airplane-boat-spawned false
  set check-american-airstrike false
  set check-american-specialforces false

  set check-russian-intervention false
  set check-russian-specialforces false
  set check-russian-airstrike false

  reset-ticks
end

;go is run indefinetly if the go-forever button is pressed. The code runs from the top to bottom and then loops back to the top.
to go
  if(global-conflict-level < 100)[
    allmove
    american-missilestrike
    american-airstrike
    russian-airstrike
    spawn-american-specialforces
    spawn-russian-specialforces
    conflict
    if(global-conflict-level > 0 and global-conflict-level < 100 and global-conflict-timer = 10)[
      set global-conflict-level global-conflict-level - 0.1
      set global-conflict-timer 0
    ]
    set global-conflict-timer global-conflict-timer + 1
    tick
  ]
  if(global-conflict-level >= 100)[
    gameover
  ]
end

;this method spawns the oppostion forces for the model.
to spawn-opposition-forces
  ask n-of 400 patches with [id = "conflictcountry"][sprout-opposition-forces 1]
  ask opposition-forces [set color orange set size 0.7]
end

;this method spawns the national forces for the model.
to spawn-national-forces
  ask n-of 100 patches with [id = "conflictcountry"][sprout-national-forces 1]
  ask national-forces [set color green set size 0.7]
end

;this method moves all of the agents that should be moved in the model.
;It also checks if there are any special forces deployed and if there are it adds to the war cost of the team that owns them.
to allmove
  ask national-forces [move]
  ask opposition-forces [move]
  ask russian-forces [move]
  if(count russian-specialforces > 0)[
    ask russian-specialforces [move]
    set russian-cost russian-cost + 0.01
    set global-conflict-level global-conflict-level + 0.05
  ]
  if(count american-specialforces > 0)[
    ask american-specialforces [move]
    set american-cost american-cost + 0.01
    set american-publicapproval american-publicapproval - 0.05
    set global-conflict-level global-conflict-level + 0.05
  ]
  ask rockets [move-rockets]
  ask airplanes [move-airplanes]
end

;general move method. Moves forward 0.5, and makes sure to stay within the country.
to move
  set heading random 360
  let front-patches patches in-cone 2 75
  if one-of front-patches != nobody and [id] of one-of front-patches != "conflictcountry"[
    set heading heading - 180
  ]
  forward 0.50
end

;move method specifically for rockets.
to move-rockets
  ask rockets [
      if(target = nobody)[
        if(typeid = "american-rockets")[
          if(count national-forces > 0)[
            set target one-of national-forces
          ]
          if(count national-forces = 0)[
            die
          ]
        ]
        if(typeid = "russian-rockets")[
          if(count opposition-forces > 0)[
            set target one-of opposition-forces
          ]
          if(count opposition-forces = 0)[
            die
          ]
        ]
      ]

      if(one-of turtles in-radius 1 != target)[
        face target fd 0.3
      ]
      if(one-of turtles in-radius 1 = target)[
        let i 0
        while[i < 200][ask patches in-radius 2 with[pcolor = 49.5][set pcolor yellow set pcolor 49.5] set i i + 1]
        ask turtles in-radius 1 [die]
        die
      ]
      if(count rockets with [typeid = "american-rockets"] = 0)[
        set check-american-missilestrike false
      ]
    ]
end

;move method specifically for airplanes
to move-airplanes
  ask airplanes[
      if(target = nobody or target = 0)[
        if(typeid = "american-airplane")[
          if(count national-forces > 0)[
            set target one-of national-forces
          ]
          if(count national-forces = 0)[
            set target one-of boats
            die
            set check-american-airstrike false
          ]
        ]
        if(typeid = "russian-airplane")[
          if(count opposition-forces > 0)[
            set target one-of opposition-forces
          ]
          if(count opposition-forces = 0)[
            set target patch 30 28
          ]
        ]
      ]
      if(typeid = "american-airplane")[
        if(one-of turtles in-radius 2 != target)[
          face target fd 0.4
        ]
        if(one-of turtles in-radius 2 = target and [breed] of target = national-forces)[
          let i 0
          while[i < 200][ask patches in-radius 3 with[pcolor = 49.5][set pcolor yellow set pcolor 49.5] set i i + 1]
          ask national-forces in-radius 2 [die]
          set global-conflict-level global-conflict-level + 2
          set american-publicapproval american-publicapproval + 2
          set american-cost american-cost + 2.5
          set target one-of boats with [typeid = "american-airplaneboat"]
        ]
        if(one-of turtles in-radius 2 = target and [breed] of target = boats)[
          set target one-of national-forces
        ]
      ]
      if(typeid = "russian-airplane")[
        if(one-of turtles in-radius 2 != target)[
        face target fd 0.2
        ]
        if(one-of turtles in-radius 2 = target)[
          let i 0
          while[i < 200][ask patches in-radius 3 with[pcolor = 49.5][set pcolor yellow set pcolor 49.5] set i i + 1]
          ask opposition-forces in-radius 2 [die]
          set global-conflict-level global-conflict-level + 2
          set russian-cost russian-cost + 2.5
          set target patch 30 28
          show target
        ]
        if(one-of patches in-radius 2 = target)[
          die
        ]
      ]
    ]
end

;this method makes the different forces attack each other, if the civilwar button is on.
to conflict
  if(civilwar = true)[
    ask opposition-forces [opposition-forces-attack]
    ask national-forces [national-forces-attack]

    ask russian-specialforces [russian-specialforces-attack]
    ask american-specialforces [american-specialforces-attack]
  ]
end

;attack method for the national forces
to national-forces-attack
  if(any? opposition-forces-here)[
    let defense-of-opponent 0
    let id-of-opponent 0
    ask one-of opposition-forces-here[set defense-of-opponent armour set id-of-opponent who]
    if([pcolor] of patch-here = green + 2)[
      if(proficiency * arms > defense-of-opponent and random 10000 > 9950)[
      ask turtle id-of-opponent [die]
      ]
    ]
    if([pcolor] of patch-here = orange + 2)[
      if(proficiency * arms > defense-of-opponent + 1)[
      ask turtle id-of-opponent [die]
      ask patch-here [set pcolor green + 2]
      ]
    ]
  ]
  if(count opposition-forces-here = 0)[
    ask patch-here [set pcolor green + 2]
  ]
end

;attack method for the opposition forces
to opposition-forces-attack
  if(any? national-forces-here)[
    let defense-of-opponent 0
    let id-of-opponent 0
    ask one-of national-forces-here[set defense-of-opponent armour set id-of-opponent who]
    if([pcolor] of patch-here = green + 2)[
      if(proficiency * arms > defense-of-opponent and random 10000 > 9950)[
      ask turtle id-of-opponent [die]
      ]
    ]
    if([pcolor] of patch-here = orange + 2)[
      if(proficiency * arms > defense-of-opponent + 0.5)[
      ask turtle id-of-opponent [die]
      ask patch-here [set pcolor orange + 2]
      ]
    ]
  ]
  if(count national-forces-here = 0)[
    ask patch-here [set pcolor orange + 2]
  ]
end

;attack method for the american special forces
to american-specialforces-attack
  if(any? national-forces-here)[
    let defense-of-opponent 0
    let id-of-opponent 0
    ask one-of national-forces-here[set defense-of-opponent armour set id-of-opponent who]
    if([pcolor] of patch-here = green + 2)[
      if(proficiency * arms > defense-of-opponent and random 10000 > 9950)[
      ask turtle id-of-opponent [die]
      ]
    ]
    if([pcolor] of patch-here = orange + 2)[
      if(proficiency * arms > defense-of-opponent + 0.5)[
      ask turtle id-of-opponent [die]
      ask patch-here [set pcolor orange + 2]
      ]
    ]
  ]
  if(count national-forces-here = 0)[
    ask patch-here [set pcolor orange + 2]
  ]
end

;attack method for the russian special forces
to russian-specialforces-attack
  if(any? opposition-forces-here)[
    let defense-of-opponent 0
    let id-of-opponent 0
    ask one-of opposition-forces-here[set defense-of-opponent armour set id-of-opponent who]
    if([pcolor] of patch-here = orange + 2)[
      if(proficiency * arms > defense-of-opponent and random 10000 > 9950)[
      ask turtle id-of-opponent [die]
      ]
    ]
    if([pcolor] of patch-here = green + 2)[
      if(proficiency * arms > defense-of-opponent + 0.5)[
      ask turtle id-of-opponent [die]
      ]
    ]
  ]
end

;method for russian arms sale
to russian-armssale
  set russian-profit russian-profit + 5.0
  ask national-forces [set arms arms + 0.1]
end

;method for american arms assistance
to american-armsassistance
  set american-cost american-cost + 10.0
  ask opposition-forces [set arms arms + 0.2]
end

;check if the american missilestrike button is active
to set-american-missilestrike
  let break false
  if(check-american-missilestrike = true and break = false)[
    set check-american-missilestrike false
    set break true
  ]
  if(check-american-missilestrike = false and break = false)[
    set check-american-missilestrike true
    set break true
  ]
end

;method for american missilestrike
to american-missilestrike
  if(count rockets with[typeid = "american-rockets"] = 0)[
    ;check if missile strikes are on
    if(check-american-missilestrike = true)[

      if(count national-forces > 0)[

        set global-conflict-level global-conflict-level + 5
        set american-publicapproval american-publicapproval + 5
        set american-cost american-cost + 8.0

        ;check if boat is spawned, else spawn it
        if(american-missile-boat-spawned = false)[
          create-boats 1 [set xcor -30 set ycor 10 set size 4.5 set color grey set heading 90 set typeid "american-missileboat"]
          let i 0
          while[i <= 400][ask boats with [typeid = "american-missileboat"][fd 0.01 set heading 90 - i * 0.22] set i i + 1]
          set american-missile-boat-spawned true
        ]

        ;execute american airstrike
        ask boats with [typeid = "american-missileboat"][hatch-rockets 3 [set size 1 set color blue set typeid "american-rockets"]]
        ask rockets with [typeid = "american-rockets"][set target one-of national-forces]

      ]

    ]

  ]
  ;despawn boat
  if(american-missile-boat-spawned = true and check-american-missilestrike = false)[
    let i 0
    ask boats [while[i <= 400][ask boats [fd 0.01 set heading 0 - i * 0.22] set i i + 1]]
    ask boats with [typeid = "american-missileboat"][die]
    set american-missile-boat-spawned false
  ]
end

;check if the american airstrike button is active
to set-american-airstrike
  let break false
  if(check-american-airstrike = true and break = false)[
    set check-american-airstrike false
    set break true
  ]
  if(check-american-airstrike = false and break = false)[
    set check-american-airstrike true
    set break true
  ]
end

;method for the american airstrike
to american-airstrike
  ;check if airstrikes strikes are on
  if(check-american-airstrike = true)[
    if(count national-forces > 0)[

      ;check if boat is spawned, else spawn it
      if(american-airplane-boat-spawned = false)[
        create-boats 1 [set xcor -30 set ycor 0 set size 4.5 set color grey set heading 90 set typeid "american-airplaneboat"]
        let i 0
        while[i <= 400][ask boats with[typeid = "american-airplaneboat"][fd 0.01 set heading 90 - i * 0.22] set i i + 1]
        set american-airplane-boat-spawned true
      ]

      ;execute american airstrike
      if(count airplanes with[typeid = "american-airplane"] = 0)[
        ask boats with[typeid = "american-airplaneboat"][hatch-airplanes 1 [set size 2 set color blue set typeid "american-airplane"]]
        ask airplanes with[typeid = "american-airplane"][set target one-of national-forces]
      ]
    ]
  ]
  ;despawn boat
   if(american-airplane-boat-spawned = true and check-american-airstrike = false)[
    ask airplanes with[typeid = "american-airplane"][set target one-of boats with[typeid = "american-airplaneboat"]]
    ask airplanes with[typeid = "american-airplane"][while[count boats-here = 0][fd 0.1 face target]]
    ask airplanes with [typeid = "american-airplane"][die]
    let i 0
    ask boats [while[i <= 400][ask boats [fd 0.01 set heading 0 - i * 0.22] set i i + 1]]
    ask boats with[typeid = "american-airplaneboat"][die]
    set american-airplane-boat-spawned false
  ]
end

;check if the russian airstrike button is active
to set-russian-airstrike
  let break false
  if(check-russian-airstrike = true and break = false)[
    set check-russian-airstrike false
    set break true
  ]
  if(check-russian-airstrike = false and break = false)[
    set check-russian-airstrike true
    set break true
  ]
end

;method for the russian airstrike
to russian-airstrike
  ;check if airstrikes strikes are on
  if(check-russian-airstrike = true)[
    if(count opposition-forces > 0)[

      ;execute russian airstrike
      if(count airplanes with[typeid = "russian-airplane"] = 0)[
        ask patch 30 28 [sprout-airplanes 4 [set size 2 set color red set typeid "russian-airplane"]]
        set russian-cost russian-cost + 5
      ]
      ]
    ]
end

;check if the america specialforces button is active
to set-american-specialforces
let break false
  if(check-american-specialforces = true and break = false)[
    set check-american-specialforces false
    set break true
  ]
  if(check-american-specialforces = false and break = false)[
    set check-american-specialforces true
    set break true
  ]
end

;method to spawn american specialeforces
to spawn-american-specialforces
  if(check-american-specialforces = true and count american-specialforces < 1)[
    ask n-of 1 patches with [id = "conflictcountry"][sprout-american-specialforces 3]
    ask american-specialforces [set color blue set size 1]
    ask american-specialforces [set armour 5 set arms 5 set proficiency 5]
  ]
  if(check-american-specialforces = false)[
    ask american-specialforces [die]
  ]
end

;check if the russian specialforces button is active
to set-russian-specialforces
let break false
  if(check-russian-specialforces = true and break = false)[
    set check-russian-specialforces false
    set break true
  ]
  if(check-russian-specialforces = false and break = false)[
    set check-russian-specialforces true
    set break true
  ]
end

;method to spawn russian specialforces
to spawn-russian-specialforces
  if(check-russian-specialforces = true and count russian-specialforces < 1)[
    ask n-of 1 patches with [id = "conflictcountry"][sprout-russian-specialforces 3]
    ask russian-specialforces [set color red set size 1]
    ask russian-specialforces [set armour 5 set arms 5 set proficiency 5]
  ]
  if(check-russian-specialforces = false)[
    ask russian-specialforces [die]
  ]
end

;sell russian missile to national-forces
to russian-missilesale
    if(count national-forces > 0 and count opposition-forces > 0)[
      set global-conflict-level global-conflict-level + 5
      set russian-profit russian-profit + 8.0
      ask n-of 3 national-forces[hatch-rockets 1 [set size 1 set color red set typeid "russian-rockets"]]
      ask rockets with [typeid = "russian-rockets"][set target one-of opposition-forces]
    ]
end

;kill all turtles and display the game over screen.
to gameover
  ask turtles [die]
  ask patches [set pcolor black]
  import-pcolors "gameover.jpg"
end
@#$#@#$#@
GRAPHICS-WINDOW
257
10
775
529
-1
-1
8.361
1
10
1
1
1
0
0
0
1
-30
30
-30
30
0
0
1
ticks
30.0

BUTTON
8
13
74
46
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
79
13
145
46
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
20
348
237
381
NIL
set-american-airstrike
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
21
384
236
417
NIL
set-american-missilestrike
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
799
344
1014
377
NIL
russian-armssale
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SWITCH
150
14
253
47
civilwar
civilwar
0
1
-1000

MONITOR
841
517
942
554
Arms level
mean [arms] of national-forces
17
1
9

MONITOR
840
561
942
598
Proficiency level
mean [proficiency] of national-forces
17
1
9

MONITOR
840
604
943
641
Armour level
mean [armour] of national-forces
17
1
9

MONITOR
83
525
184
562
Arms level
mean [arms] of opposition-forces
17
1
9

MONITOR
83
570
184
607
Proficiency level
mean [proficiency] of opposition-forces
2
1
9

MONITOR
85
613
185
650
Armour level
mean [armour] of opposition-forces
17
1
9

PLOT
513
529
822
717
Territories controlled
NIL
NIL
0.0
10.0
0.0
2000.0
true
false
"" ""
PENS
"default" 1.0 0 -8330359 true "" "plot count patches with [pcolor = green + 2]"
"pen-1" 1.0 0 -612749 true "" "plot count patches with [pcolor = orange + 2]"

PLOT
203
529
513
717
Remaining forces
NIL
NIL
0.0
10.0
0.0
500.0
true
false
"" ""
PENS
"default" 1.0 2 -10899396 true "" "plot count national-forces"
"pen-1" 1.0 2 -955883 true "" "plot count opposition-forces"

PLOT
23
88
237
208
American public approval
NIL
%
0.0
10.0
0.0
100.0
true
false
"" ""
PENS
"default" 1.0 0 -13345367 true "" "plot american-publicapproval"

PLOT
23
206
237
340
American war cost
NIL
million $
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -5987164 true "" "plot american-cost"

TEXTBOX
117
63
267
82
USA
15
105.0
1

TEXTBOX
877
177
1027
196
RUSSIA
15
15.0
1

PLOT
798
204
1018
339
Russian war cost & profit
NIL
million $
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -13840069 true "" "plot russian-profit"
"pen-1" 1.0 0 -5987164 true "" "plot russian-cost"

BUTTON
21
423
236
456
NIL
set-american-specialforces
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
799
382
1014
415
NIL
set-russian-airstrike\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
21
461
236
494
NIL
american-armsassistance
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
799
420
1014
453
NIL
set-russian-specialforces
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
799
457
1014
490
NIL
russian-missilesale
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
796
10
1016
169
Global Conflict Level
NIL
%
0.0
10.0
0.0
100.0
true
false
"" ""
PENS
"default" 1.0 0 -2674135 true "" "plot global-conflict-level"

TEXTBOX
841
495
928
513
National forces
11
0.0
1

TEXTBOX
83
504
184
522
Opposition forces
11
0.0
1

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

boat top
true
0
Polygon -7500403 true true 150 1 137 18 123 46 110 87 102 150 106 208 114 258 123 286 175 287 183 258 193 209 198 150 191 87 178 46 163 17
Rectangle -16777216 false false 129 92 170 178
Rectangle -16777216 false false 120 63 180 93
Rectangle -7500403 true true 133 89 165 165
Polygon -11221820 true false 150 60 105 105 150 90 195 105
Polygon -16777216 false false 150 60 105 105 150 90 195 105
Rectangle -16777216 false false 135 178 165 262
Polygon -16777216 false false 134 262 144 286 158 286 166 262
Line -16777216 false 129 149 171 149
Line -16777216 false 166 262 188 252
Line -16777216 false 134 262 112 252
Line -16777216 false 150 2 149 62

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

person soldier
false
0
Rectangle -7500403 true true 127 79 172 94
Polygon -10899396 true false 105 90 60 195 90 210 135 105
Polygon -10899396 true false 195 90 240 195 210 210 165 105
Circle -7500403 true true 110 5 80
Polygon -10899396 true false 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Polygon -6459832 true false 120 90 105 90 180 195 180 165
Line -6459832 false 109 105 139 105
Line -6459832 false 122 125 151 117
Line -6459832 false 137 143 159 134
Line -6459832 false 158 179 181 158
Line -6459832 false 146 160 169 146
Rectangle -6459832 true false 120 193 180 201
Polygon -6459832 true false 122 4 107 16 102 39 105 53 148 34 192 27 189 17 172 2 145 0
Polygon -16777216 true false 183 90 240 15 247 22 193 90
Rectangle -6459832 true false 114 187 128 208
Rectangle -6459832 true false 177 187 191 208

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

rocket
true
0
Polygon -7500403 true true 120 165 75 285 135 255 165 255 225 285 180 165
Polygon -1 true false 135 285 105 135 105 105 120 45 135 15 150 0 165 15 180 45 195 105 195 135 165 285
Rectangle -7500403 true true 147 176 153 288
Polygon -7500403 true true 120 45 180 45 165 15 150 0 135 15
Line -7500403 true 105 105 135 120
Line -7500403 true 135 120 165 120
Line -7500403 true 165 120 195 105
Line -7500403 true 105 135 135 150
Line -7500403 true 135 150 165 150
Line -7500403 true 165 150 195 135

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
